package com.yiqi.app.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.app.domain.AppBanner;
import org.apache.ibatis.annotations.Mapper;

/**
 * 轮播图及启动页广告配置Mapper接口
 *
 * @author xiaohei
 * @date 2023-08-08
 */
@Mapper
public interface AppBannerMapper extends BaseMapper<AppBanner> {
    /**
     * 查询轮播图及启动页广告配置
     *
     * @param id 轮播图及启动页广告配置主键
     * @return 轮播图及启动页广告配置
     */
    public AppBanner selectAppBannerById(Long id);

    /**
     * 查询轮播图及启动页广告配置列表
     *
     * @param appBanner 轮播图及启动页广告配置
     * @return 轮播图及启动页广告配置集合
     */
    public List<AppBanner> selectAppBannerList(AppBanner appBanner);

    /**
     * 新增轮播图及启动页广告配置
     *
     * @param appBanner 轮播图及启动页广告配置
     * @return 结果
     */
    public int insertAppBanner(AppBanner appBanner);

    /**
     * 修改轮播图及启动页广告配置
     *
     * @param appBanner 轮播图及启动页广告配置
     * @return 结果
     */
    public int updateAppBanner(AppBanner appBanner);

    /**
     * 删除轮播图及启动页广告配置
     *
     * @param id 轮播图及启动页广告配置主键
     * @return 结果
     */
    public int deleteAppBannerById(Long id);

    /**
     * 批量删除轮播图及启动页广告配置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppBannerByIds(Long[] ids);
}
